#
# spec file for package influxdb
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1230 || 0%{?rhel_version} > 6 || 0%{?centos_version} > 6 || 0%{?fedora_version} >= 20 || 0%{?el7}%{?fc20}%{?fc21}%{?fc22}
%bcond_without systemd
%else
%bcond_with    systemd
%endif

Name:           influxdb
Summary:        Scalable datastore for metrics, events, and real-time analytics
License:        MIT
Group:          Productivity/Databases/Servers
Version:        1.5.4
Release:        9.8
Url:            https://github.com/influxdata/influxdb
Source:         %{name}-%{version}.tar.xz
Source1:        influxdb.service
Source2:        influxdb.tmpfiles
Source3:        influxdb.init
Source4:        Compability_note.txt
Source5:        README.packaging
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  go >= 1.10.3
BuildRequires:  golang-packaging >= 15.0.8
BuildRequires:  xmlto
%if %{with systemd}
BuildRequires:  systemd-rpm-macros
%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}
%endif
Requires(pre):  pwdutils
%if %{with systemd}
%{systemd_requires}
Requires(post): systemd
%else
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
%endif

%description
InfluxDB is an distributed time series database with no external dependencies.
It's useful for recording metrics, events, and performing analytics.

%package devel
Summary:        InfluxDB development files
Group:          Development/Languages/Golang
Requires:       go

%description devel
Go sources and other development files for InfluxDB

%prep
%setup -q -n %{name}-%{version}

%build
# Disable phone-home to usage.influxdata.com
sed -i 's/.*reporting-disabled = false/reporting-disabled = true/' etc/config.sample.toml
%goprep github.com/influxdata/influxdb
%gobuild -ldflags="-X main.version=%{version}" cmd/...

make -C ./man build

%install
%gosrc
%fdupes -s %{buildroot}/%{go_contribsrcdir}/github.com/influxdata/influxdb

mkdir -p %{buildroot}%{_sysconfdir}/influxdb
install -D -m 644 etc/config.sample.toml %{buildroot}%{_sysconfdir}/influxdb/config.toml
mkdir -p %{buildroot}%{_localstatedir}/log/influxdb
mkdir -p %{buildroot}%{_localstatedir}/lib/influxdb
mkdir -p %{buildroot}%{_localstatedir}/lib/influxdb/{data,meta,hh,wal}
mkdir -p %{buildroot}%{_sbindir}
%if %{with systemd}
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/influxdb.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcinfluxdb
install -D -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/influxdb.conf
%else
install -D -m 0755 %{S:3} %{buildroot}%{_sysconfdir}/init.d/influxdb
ln -s -f %{_sysconfdir}/init.d/influxdb %{buildroot}%{_sbindir}/rcinfluxdb
mkdir -p %{buildroot}%{_localstatedir}/run/influxdb
%endif
install -D -m 0755 %{_builddir}/go/bin/* %{buildroot}%{_bindir}

# Warn about compatibility problems with previous version
mkdir -p %{buildroot}%{_localstatedir}/adm/update-messages/
cp -v %{SOURCE4} %{buildroot}%{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}

make -C ./man install DESTDIR=%{buildroot}%{_prefix}

%check
#%%gotest github.com/influxdata/influxdb

%pre
getent group influxdb >/dev/null || groupadd -r influxdb
getent passwd influxdb >/dev/null || useradd -r -g influxdb \
	-d %{_localstatedir}/lib/influxdb \
	-s /sbin/nologin \
	-c "user for InfluxDB database server" influxdb
%if %{with systemd}
%service_add_pre influxdb.service
%endif

%preun
%if %{with systemd}
%service_del_preun influxdb.service
%else
%stop_on_removal influxdb
%endif

%if %{with systemd}
%post
%tmpfiles_create %_tmpfilesdir/influxdb.conf
%service_add_post influxdb.service
%endif

%postun
%if %{with systemd}
%service_del_postun influxdb.service
%else
%restart_on_update influxdb
%insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%license LICENSE LICENSE_OF_DEPENDENCIES.md
%doc QUERIES.md README.md CHANGELOG.md
%dir %{_sysconfdir}/influxdb
%config(noreplace) %attr(0640 root,influxdb) %{_sysconfdir}/influxdb/config.toml
%{_bindir}/influx
%{_bindir}/influx_inspect
%{_bindir}/influxd
%{_bindir}/influx_stress
%{_bindir}/influx_tsm
%{_bindir}/store
%{_sbindir}/rcinfluxdb
%if %{with systemd}
%{_unitdir}/influxdb.service
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/influxdb.conf
%else
/etc/init.d/influxdb
%attr(0755, influxdb, influxdb) %dir %{_rundir}/influxdb
%endif
%attr(0755, influxdb, influxdb) %dir %{_localstatedir}/log/influxdb
%attr(0755, influxdb, influxdb) %dir %{_localstatedir}/lib/influxdb
%attr(0755, influxdb, influxdb) %dir %{_localstatedir}/lib/influxdb/meta
%attr(0755, influxdb, influxdb) %dir %{_localstatedir}/lib/influxdb/data
%attr(0755, influxdb, influxdb) %dir %{_localstatedir}/lib/influxdb/hh
%attr(0700, influxdb, influxdb) %dir %{_localstatedir}/lib/influxdb/wal
%{_mandir}/man1/influx.1.gz
%{_mandir}/man1/influx_inspect.1.gz
%{_mandir}/man1/influx_stress.1.gz
%{_mandir}/man1/influx_tsm.1.gz
%{_mandir}/man1/influxd-backup.1.gz
%{_mandir}/man1/influxd-config.1.gz
%{_mandir}/man1/influxd-restore.1.gz
%{_mandir}/man1/influxd-run.1.gz
%{_mandir}/man1/influxd-version.1.gz
%{_mandir}/man1/influxd.1.gz
%{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}

%files devel
%defattr(-,root,root,-)
%license LICENSE LICENSE_OF_DEPENDENCIES.md
%dir %{go_contribsrcdir}/github.com
%dir %{go_contribsrcdir}/github.com/influxdata
%{go_contribsrcdir}/github.com/influxdata/influxdb

%changelog
* Thu Jan 24 2019 tbechtold@suse.com
- Fix permissions and add (noreplace) for /etc/influxdb/config.toml
  The file should be readable by the influxdb group and not readable by
  anybody else. Also it shouldn't be replaced on package upgrades
  when the file was modified.
- Use %%license macro
- Use %%tmpfiles_create macro when systemd is used
- Use /run instead of /var/run
* Fri Oct  5 2018 matwey.kornilov@gmail.com
- Don't use double underscored macro
* Thu Sep 20 2018 matwey.kornilov@gmail.com
- Put README.packaging into Source
* Sun Jul 29 2018 matwey.kornilov@gmail.com
- Update 1.5.4:
  * [1.5] Fix panic in readTombstoneV4.
  * buildtsi: Do not escape measurement names.
  * Fix the validation for multiple nested distinct calls.
  * Return the correct auxiliary values for top/bottom.
  * backport: check for failure case where backup dir has no manifest files.
  * Fix regression to allow now() to be used as the group by offset again.
  * 1.5: Revert "Use MADV_WILLNEED when loading TSM files".
  * Ignore index size in Engine.DiskSize().
  * [1.5] Fix buildtsi partition key.
  * Ensure that conditions are encoded correctly even if the AST is not properly formed.
  * Allow time variable to be case insensitive again.
  * Support setting the log level through the environment variable.
  * Ensure correct number of tags parsed.
  * Fix panic when checking fieldsets.
  * Fix data race in WAL.
  * Improve CLI connection warnings
  * Backup utility prints a list of backup files.
  * Backup/Restore can produce/consume data in the same format as the enterprise backup/restore tool.
  * Restore runs in online mode, does not delete existing databases
  * Export functionality using start/end to filter exported data by timestamp
  * Handle high cardinality deletes in TSM engine
  * Improve inmem index startup performance for high cardinality.
  * Add further tsi support for streaming/copying shards.
  * Schedule a full compaction after a successful import
  * Add Prometheus /metrics endpoint.
  * Add ability to generate shard digests.
  * Allow setting the node id in the influx cli program.
  * Add logging configuration to the main configuration file.
  * Suppress the InfluxDB banner if the log output is not a TTY.
  * Added option to write HTTP request logs to separate file.
  * Update logging calls to take advantage of structured logging.
  * Generate trace logs for a number of important InfluxDB operations.
  * Improve startup time of inmem index.
* Tue Jun 19 2018 jberry@suse.com
- Include LimitNOFILE=100000 in service file as influxdb suggests
  and crashes with relatively small amounts of data without this.
* Mon Feb 12 2018 matwey.kornilov@gmail.com
- Pass version to linker (fix boo#1079997)
* Mon Feb 12 2018 matwey.kornilov@gmail.com
- inxludb 1.4 requires go 1.9
* Sat Dec 23 2017 matwey.kornilov@gmail.com
- Require go in influxdb-devel package.
- Fix build for openSUSE Leap 42.x
* Fri Dec  8 2017 matwey.kornilov@gmail.com
- Version 1.3.8:
  * Add 'influx_inspect inmem2tsi' command.
  * Fix race condition in the merge iterator close method.
  * Fix compaction aborting early and dropping remaining series
* Sat Dec  2 2017 tuukka.pasanen@ilmi.fi
- 1.4.0 - v1.4.2
  Breaking changes (PLEASE READ!)
  You can no longer specify a different ORDER BY clause in a subquery than the one in the top
  level query. This functionality never worked properly, but was not explicitly forbidden.
  As part of the ongoing development of the tsi1 index, the implementation of a Bloom Filter,
  used to efficiently determine if series are not present in the index, was altered in #8857.
  While this significantly increases the performance of the index and reduces its memory
  consumption, the existing tsi1 indexes created while running previous versions of the database
  are not compatible with 1.4.0.
  Users with databases using the tsi1 index must go through the following process to upgrade to
  1.4.0:
  1 Stop influxd.
  2 Remove all index directories on databases using the tsi1 index.
    With default configuration these can be found in
    /var/lib/influxdb/data/DB_NAME/RP_NAME/SHARD_ID/index or
    ~/.influxdb/data/DB_NAME/RP_NAME/SHARD_ID/index.
    It's worth noting at this point how many different shard_ids you visit.
  3 Run the influx_inspect inmem2tsi tool using the shard's data and WAL
    directories for -datadir and -waldir, respectively. Given the example
    in step (2) that would be influx_inspect inmem2tsi -datadir
    /var/lib/influxdb/data/DB_NAME/RP_NAME/SHARD_ID
  - waldir /path/to/influxdb/wal/DB_NAME/RP_NAME/SHARD_ID.
  4 Repeat step (3) for each shard that needs to be converted.
    Start influxd.
  Users with existing tsi1 shards, who attempt to start version 1.4.0 without following the
  above steps, will find the shards refuse to open, and will most likely see the following
  error message:
    incompatible tsi1 index MANIFEST
    Configuration Changes
  [collectd] Section
  parse-multivalue-plugin was added with a default of split. When set to split, multivalue
  plugin data (e.g. df free:5000,used:1000) will be split into separate measurements (e.g.,
  (df_free, value=5000) (df_used, value=1000)). When set to join, multivalue plugin will be
  stored as a single multi-value measurement (e.g., (df, free=5000,used=1000)).
  * Fix panic: runtime error: slice bounds out of range
  * Fix descending cursors and range queries via IFQL RPC API.
  * 'X-Influxdb-Build' to http response headers so users can identify if a response
    is from an OSS or Enterprise service.
  * Add parse-multivalue-plugin to allow users to choose how multivalue plugins should
    be handled by the collectd service.
  * Allow panic recovery to be disabled when investigating server issues.
  * Support http pipelining for /query endpoint.
  * Reduce allocations when reading data
  * Mutex profiles are now available.
  * TSI Index Migration Tool
  * Support SHOW CARDINALITY queries.
  * Batch up writes for monitor service
  * All errors from queries or writes are available via X-InfluxDB-Error header, and 5xx
    error messages will be written to server logs.
  * Improve test coverage across both indexes.
  * Respect X-Request-Id/Request-Id headers.
  * InfluxDB now uses MIT licensed version of BurntSushi/toml.
  * Use system cursors for measurement, series, and tag key meta queries.
  * Support Ctrl+C to cancel a running query in the Influx CLI. Thanks @emluque!
  * Initial implementation of explain plan.
  * Include the number of scanned cached values in the iterator cost.
  * Add support for the Prometheus remote read and write APIs.
  * Improve performance of Include and Exclude functions
  * Report the task status for a query.
  * Reduce allocations, improve readEntries performance by simplifying loop
  * Separate importer log statements to stdout and stderr.
  * Improve performance of Bloom Filter in TSI index.
  * Add message pack format for query responses.
  * Improved compaction scheduling
  * Implicitly decide on a lower limit for fill queries when none is present.
  * Add EXPLAIN ANALYZE command, which produces a detailed execution plan of a SELECT
    statement.- #8963: Streaming inmem2tsi conversion.
  * Sort & validate TSI key value insertion.
  * Make client errors more helpful on downstream errs. Thanks @darkliquid!
  * EXACT and estimated CARDINALITY queries.
  * Handle nil MeasurementIterator.
  * Add long-line support to client importer. Thanks @lets00!
  * Update to go 1.9.2
  * Allow human-readable byte sizes in config
  * Improve SHOW TAG KEYS performance.
  * Create a command to truncate shard groups
  * Change the default stats interval to 1 second instead of 10 seconds.
  * illumos build broken on syscall.Mmap
  * Prevent privileges on non-existent databases from being set.
  * influxd backup tool will now separate out its logging to stdout and stderr. Thanks
    @xginn8!
  * Dropping measurement used several GB disk space
  * Fix the cq start and end times to use unix timestamps.
  * influx cli case sensitivity.
  * Fixed time boundaries for continuous queries with time zones.
  * Return query parsing errors in CSV formats.
  * Fix time zone shifts when the shift happens on a time zone boundary.
  * Parse time literals using the time zone in the select statement.
  * Reduce CPU usage when checking series cardinality
  * Fix backups when snapshot is empty.
  * Cursor leak, resulting in an accumulation of .tsm.tmp files after compactions.
  * Improve condition parsing.
  * Ensure inputs are closed on error. Add runtime GC finalizer as additional guard to
    close iterators
  * Fix merging bug on system iterators.
  * Force subqueries to match the parent queries ordering.
  * Fix race condition accessing seriesByID map.
  * Fix deadlock when calling SeriesIDsAllOrByExpr
  * Fix influx_inspect export so it skips missing files.
  * Reduce how long it takes to walk the varrefs in an expression.
  * panic: runtime error: invalid memory address or nil pointer dereference.
  * Drop Series Cause Write Fail/Write Timeouts/High Memory Usage
  * Fix increased memory usage in cache and wal readers
  * An OSS read-only user should be able to list measurements on a database
  * Ensure time and tag-based condition can be used with tsi1 index when deleting.
  * Prevent deadlock when doing math on the result of a subquery.
  * Fix a minor memory leak in batching points in tsdb.
  * Don't assume which is present in package post-install script.
  * Fix missing man pages in new packaging output
  * Fix use of INFLUXD_OPTS in service file
  * Fix WAL panic: runtime error: makeslice: cap out of range
  * Copy returned bytes from TSI meta functions.
  * Fix data deleted outside of time range
  * Fix data dropped incorrectly during compaction
  * Prevent deadlock during collectd, graphite, opentsdb, and udp shutdown.
  * Remove the pidfile after the server has exited.
  * Return query.ErrQueryInterrupted for successful read on InterruptCh.
  * Fix race inside Measurement index.
  * Ensure retention service always removes local shards.
  * Handle utf16 files when reading the configuration file.
  * Fix panic: runtime error: slice bounds out of range
* Fri Dec  1 2017 tuukka.pasanen@ilmi.fi
- Version 1.3.7
  * Don't assume which is present in package post-install script.
  * Fix use of INFLUXD_OPTS in service file
  * Fix missing man pages in new packaging output
  * Add RPM dependency on shadow-utils for useradd.
  * Fix data deleted outside of time range
  * Fix data dropped incorrectly during compaction
  * Return query.ErrQueryInterrupted for a successful read on InterruptCh.
  * Copy returned bytes from TSI meta functions.
* Sun Oct 15 2017 matwey.kornilov@gmail.com
- Version 1.3.6:
  * Reduce how long it takes to walk the varrefs in an expression.
  * panic: runtime error: invalid memory address or nil pointer dereference.
  * Fix increased memory usage in cache and wal readers
  * Prevent deadlock when doing math on the result of a subquery.
  * Fix several races in the shard and engine.
  * Fix race on cache entry.
* Sat Sep  2 2017 matwey.kornilov@gmail.com
- Version 1.3.5:
  * Fix race condition accessing seriesByID map.
  * Fix deadlock when calling SeriesIDsAllOrByExpr
* Sat Aug 26 2017 matwey.kornilov@gmail.com
- Version 1.3.4:
  * Fixed time boundaries for continuous queries with time zones.
  * Fix time zone shifts when the shift happens on a time zone boundary.
  * Parse time literals using the time zone in the select statement.
  * Fix drop measurement not dropping all data
  * Fix backups when snapshot is empty.
  * Cursor leak, resulting in an accumulation of .tsm.tmp files after
    compactions.
  * Deadlock when dropping measurement and writing
  * Ensure inputs are closed on error. Add runtime GC finalizer as additional
    guard to close iterators
  * Fix leaking tmp file when large compaction aborted
  * Batch up writes for monitor service
- Version 1.3.3:
  * Resolves a memory leak when NewReaderIterator creates a nilFloatIterator,
    the reader is not closed
- Version 1.3.2:
  * Interrupt in progress TSM compactions
  * Prevent excessive memory usage when dropping series
  * Significantly improve performance of SHOW TAG VALUES.
- Version 1.3.1:
  * Ensure temporary TSM files get cleaned up when compaction aborted.
  * InfluxDB goes unresponsive
  * Duplicate points generated via INSERT after DELETE
  * Fix the cq start and end times to use unix timestamps.
- Version 1.3.0:
  * The admin UI is removed and unusable in this release. The [admin]
    configuration section will be ignored.
  * The top-level config bind-address now defaults to localhost:8088. The
    previous default was just :8088, causing the backup and restore port to
    be bound on all available interfaces (i.e. including interfaces on the
    public internet).
* Sun Jun 18 2017 matwey.kornilov@gmail.com
- Version 1.2.4:
  * The stress tool influx_stress will be removed in a subsequent
    release.
  * Remove the override of GOMAXPROCS.
  * Uncomment section headers from the default configuration file.
  * Improve write performance significantly.
  * Prune data in meta store for deleted shards.
  * Update latest dependencies with Godeps.
  * Introduce syntax for marking a partial response with chunking.
  * Use X-Forwarded-For IP address in HTTP logger if present.
  * Add support for secure transmission via collectd.
  * Switch logging to use structured logging everywhere.
  * [CLI feature request] USE retention policy for queries.
  * Add clear command to cli.
  * Adding ability to use parameters in queries in the v2 client
    using the Parameters map in the Query struct.
  * Allow add items to array config via ENV
  * Support subquery execution in the query language.
  * Verbose output for SSL connection errors.
  * Cache snapshotting performance improvements
* Wed May  3 2017 matwey.kornilov@gmail.com
- Partially revert previous change to fix build for Leap
* Thu Mar 23 2017 johannes.grassler@suse.com
- Added version linker flag to make binaries aware of which
  influxdb version they are.
- Disabled phone home to usage.influxdata.com
* Fri Mar  3 2017 johannes.grassler@suse.com
- Removed nonsensical EnvironmentFile+= line from service file
* Tue Feb 28 2017 johannes.grassler@suse.com
- Added -devel subpackage.
* Fri Dec 16 2016 matwey.kornilov@gmail.com
- Version 1.1.1:
  * Fix incorrect tag value in error message.
  * Quote the empty string as an ident.
  * Fix string fields w/ trailing slashes
* Sun Nov 13 2016 matwey.kornilov@gmail.com
- Initial version
